Stop a background fit

Description

Terminates a background job started by [ferx_fit_async](ferx_fit_async.qmd)without waiting for it to finish. Unlike pressing Ctrl+C during [ferx_collect](ferx_collect.qmd) (which cancels an active wait and kills the background process), ferx_stop() can be called at any time to terminate the job directly.

Usage

ferx_stop(handle)

Arguments

  • handle: A ferx_job handle returned by [ferx_fit_async](ferx_fit_async.qmd).

Seealso

Other fitting: [ferx_check_init](ferx_check_init.qmd)(), [ferx_collect](ferx_collect.qmd)(), [ferx_fit](ferx_fit.qmd)(), [ferx_inits_from_nca](ferx_inits_from_nca.qmd)(), [ferx_sir](ferx_sir.qmd)(), [print.ferx_job](ferx_fit_async.qmd)()

Concept

fitting

Value

Invisibly, TRUE if a running job was stopped, or FALSE if the job had already finished (nothing to stop).

Examples

ex <- ferx_example("warfarin")
handle <- ferx_fit_async(ex$model, ex$data, method = "focei")
ferx_stop(handle)